@@ -63,9 +63,9 @@ class Model:
             path.join(getcwd(), f'./{self.cape_output_folder}')
         ]
         print(f"Creating {len(output_folders)} output folders")
-        for path in output_folders:
-            if not path.isdir(dir):
-                mkdir(dir)
+        for folder in output_folders:
+            if not path.isdir(folder):
+                mkdir(folder)
 
     def pipeline_args(self, infer_config: InferConfig):
         args = {
